#!/usr/bin/env python3
"""
novel_downloader.cli
--------------------

This module exposes the CLI entry point.
"""

__all__ = ["cli_main"]

from .main import cli_main
